---
name: Bug report
about: Create a report to help us improve
labels: bug
assignees: {{ assignee }}

---

<!-- Have you searched for similar issues? Before submitting this issue, please check the open issues and add a note before logging a new issue.

PLEASE USE THE TEMPLATE BELOW TO PROVIDE INFORMATION ABOUT THE ISSUE.
THE ISSUE WILL BE CLOSED IF INSUFFICIENT INFORMATION IS PROVIDED.
-->

## Description
<!--Provide a brief description of the issue-->


## Steps to Reproduce
<!--Please add a series of steps to reproduce the issue-->

   1. {# #}
   2. {# #}
   3. {# #}

## Actual result:
<!--Please add screenshots if needed and include the Python traceback if present-->


## Expected result:


## Reproduces how often:
<!--[Easily reproduced/Intermittent issue/No steps to reproduce]-->


## Version

  * Operating System: {# #}
  * Python: {# #}
  * {{ modname }}: {# #}

## Installation source
<!-- e.g. Github repository, Github Releases, PyPI/pip, Anaconda/conda -->


## Other Additional Information:
<!--Any additional information, related issues, extra QA steps, configuration or data that might be necessary to reproduce the issue-->
